You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@libcloud.apache.org by vd...@apache.org on 2018/12/04 08:54:21 UTC

[06/23] libcloud git commit: Add cinder support LIBCLOUD-874

Add cinder support LIBCLOUD-874


Project: http://git-wip-us.apache.org/repos/asf/libcloud/repo
Commit: http://git-wip-us.apache.org/repos/asf/libcloud/commit/c4b5cfa6
Tree: http://git-wip-us.apache.org/repos/asf/libcloud/tree/c4b5cfa6
Diff: http://git-wip-us.apache.org/repos/asf/libcloud/diff/c4b5cfa6

Branch: refs/heads/trunk
Commit: c4b5cfa6a25e8f9fe373650b60e770c2b9b51235
Parents: e9dcb93
Author: micafer <mi...@upv.es>
Authored: Mon Sep 24 13:03:38 2018 +0200
Committer: Rick van de Loo <ri...@gmail.com>
Committed: Tue Dec 4 09:45:48 2018 +0100

----------------------------------------------------------------------
 libcloud/compute/drivers/openstack.py | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/libcloud/blob/c4b5cfa6/libcloud/compute/drivers/openstack.py
----------------------------------------------------------------------
diff --git a/libcloud/compute/drivers/openstack.py b/libcloud/compute/drivers/openstack.py
index bfdf082..fba9a8a 100644
--- a/libcloud/compute/drivers/openstack.py
+++ b/libcloud/compute/drivers/openstack.py
@@ -89,8 +89,8 @@ class OpenStackNetworkConnection(OpenStackBaseConnection):
     service_region = 'RegionOne'
 
 
-class OpenStackVolumeConnection(OpenStackBaseConnection):
-    service_type = 'volume'
+class OpenStackVolumeV2Connection(OpenStackBaseConnection):
+    service_type = 'volumev2'
     service_name = 'cinder'
     service_region = 'RegionOne'
 
@@ -2530,7 +2530,7 @@ class OpenStack_2_NetworkConnection(OpenStackNetworkConnection):
         return json.dumps(data)
 
 
-class OpenStack_2_VolumeConnection(OpenStackVolumeConnection):
+class OpenStack_2_VolumeV2Connection(OpenStackVolumeV2Connection):
     responseCls = OpenStack_1_1_Response
     accept_format = 'application/json'
     default_content_type = 'application/json; charset=UTF-8'
@@ -2592,8 +2592,8 @@ class OpenStack_2_NodeDriver(OpenStack_1_1_NodeDriver):
     # compute API
     # See https://developer.openstack.org/api-ref/compute/
     # For example, volume management are made in the cinder service
-    volume_connectionCls = OpenStack_2_VolumeConnection
-    volume_connection = None
+    volumev2_connectionCls = OpenStack_2_VolumeV2Connection
+    volumev2_connection = None
 
     type = Provider.OPENSTACK
 
@@ -2628,14 +2628,14 @@ class OpenStack_2_NodeDriver(OpenStack_1_1_NodeDriver):
         self.image_connection = self.connection
 
         # We run the init once to get the Cinder V2 API connection
         # and put that on the object under self.volume_connection.
         if original_ex_force_base_url or kwargs.get('ex_force_volume_url'):
             kwargs['ex_force_base_url'] = \
                 str(kwargs.pop('ex_force_volume_url',
                                original_ex_force_base_url))
-        self.connectionCls = self.volume_connectionCls
+        self.connectionCls = self.volumev2_connectionCls
         super(OpenStack_2_NodeDriver, self).__init__(*args, **kwargs)
-        self.volume_connection = self.connection
+        self.volumev2_connection = self.connection
 
         # We run the init once to get the Neutron V2 API connection
         # and put that on the object under self.network_connection.
@@ -2628,14 +2628,14 @@ class OpenStack_2_NodeDriver(OpenStack_1_1_NodeDriver):
 
         # We run the init once to get the Cinder V2 API connection
-        # and put that on the object under self.volume_connection.
+        # and put that on the object under self.volumev2_connection.
         if original_ex_force_base_url or kwargs.get('ex_force_volume_url'):
             kwargs['ex_force_base_url'] = \